format compact
format short e

%
% Case 1a. Pre-Brexit steady state with trade costs on goods only
%

load ../../steady/cases/XPtran1adj1.mat
par         = partran;

%
% Apply a Newton's method to update guesses
%
X0          = Xtran(:);
nX          = length(X0);
del         = max(abs(X0)*1e-4,1e-8);
for it=1:10;
  res       = mwtranadj(X0,par);
  for i=1:nX;
    Xp      = X0;
    Xp(i)   = X0(i)+del(i);
    dr(:,i) = (mwtranadj(Xp,par)-res)/del(i);
  end;
  S         = sparse(dr);
  X1        = X0-S\res;
  nrm       = sqrt(sum((X1-X0).^2))/length(X0);
  if (nrm<1e-10);break;end;
  X0        = X1;
end;

save mw1x.dat X0 -ascii
save mw1p.dat par -ascii



%
% Case 2a. UK raises costs on FDI from EU, sig=1==>.95
%

clear
load ../../steady/cases/XPtran1adj1.mat

%
% Find indicies in sig matrix to be changed 
%
par         = partran;
I           = partran(1);
T           = partran(2);
tem         = zeros(T,I*I);
i1          = 14+10*I+5*I*I+3*T*I+T*I*I;
i2          = i1+T*I*I;
tem(:)      = i1+1:i2;
i3          = tem(1,12);
i4          = tem(T,12);
newsig      = 1+(.95-1)*ones(T,1)./(1+exp(-([1:T]'-5)/(2*.2)));
par(i3:i4)  = newsig;

%
% Apply a Newton's method to update guesses
%
X0          = Xtran(:);
nX          = length(X0);
del         = max(abs(X0)*1e-4,1e-8);
for it=1:10;
  res       = mwtranadj(X0,par);
  for i=1:nX;
    Xp      = X0;
    Xp(i)   = X0(i)+del(i);
    dr(:,i) = (mwtranadj(Xp,par)-res)/del(i);
  end;
  S         = sparse(dr);
  X1        = X0-S\res;
  nrm       = sqrt(sum((X1-X0).^2))/length(X0);
  if (nrm<1e-10);break;end;
  X0        = X1;
end;

save mw2x.dat X0 -ascii
save mw2p.dat par -ascii



%
% Case 3a. EU raises costs on FDI from UK, sig=1==>.95
%

clear
load ../../steady/cases/XPtran1adj1.mat

%
% Find indicies in sig matrix to be changed 
%
par         = partran;
I           = partran(1);
T           = partran(2);
tem         = zeros(T,I*I);
i1          = 14+10*I+5*I*I+3*T*I+T*I*I;
i2          = i1+T*I*I;
tem(:)      = i1+1:i2;
i1          = tem(1,8);
i2          = tem(T,8);
newsig      = 1+(.95-1)*ones(T,1)./(1+exp(-([1:T]'-5)/(2*.2)));
par(i1:i2)  = newsig;

%
% Apply a Newton's method to update guesses
%
X0          = Xtran(:);
nX          = length(X0);
del         = max(abs(X0)*1e-4,1e-8);
for it=1:10;
  res       = mwtranadj(X0,par);
  for i=1:nX;
    Xp      = X0;
    Xp(i)   = X0(i)+del(i); 
    dr(:,i) = (mwtranadj(Xp,par)-res)/del(i);
  end;
  S         = sparse(dr);
  X1        = X0-S\res;
  nrm       = sqrt(sum((X1-X0).^2))/length(X0);
  if (nrm<1e-10);break;end; 
  X0        = X1;
end;


save mw3x.dat X0 -ascii
save mw3p.dat par -ascii


%
% Case 4a. UK,EU raise costs on FDI from each other, sig=1==>.95
%

clear
load ../../steady/cases/XPtran1adj1.mat

%
% Find indicies in sig matrix to be changed 
%
par         = partran;
I           = partran(1);
T           = partran(2);
tem         = zeros(T,I*I);
i1          = 14+10*I+5*I*I+3*T*I+T*I*I;
i2          = i1+T*I*I;
tem(:)      = i1+1:i2;
i1          = tem(1,8);
i2          = tem(T,8);
i3          = tem(1,12);
i4          = tem(T,12);
newsig      = 1+(.95-1)*ones(T,1)./(1+exp(-([1:T]'-5)/(2*.2)));
par(i1:i2)  = newsig;
par(i3:i4)  = newsig;

%
% Apply a Newton's method to update guesses
%
X0          = Xtran(:);
nX          = length(X0);
del         = max(abs(X0)*1e-4,1e-8);
for it=1:10;
  res       = mwtranadj(X0,par);
  for i=1:nX;
    Xp      = X0;
    Xp(i)   = X0(i)+del(i); 
    dr(:,i) = (mwtranadj(Xp,par)-res)/del(i);
  end;
  S         = sparse(dr);
  X1        = X0-S\res;
  nrm       = sqrt(sum((X1-X0).^2))/length(X0);
  if (nrm<1e-10);break;end; 
  X0        = X1;
end;

save mw4x.dat X0 -ascii
save mw4p.dat par -ascii


%
% Case 5a. UK raises costs on trade from EU, ice=0==>.05
%

clear
load ../../steady/cases/XPtran1adj1.mat

%
% Find indicies in ice matrix to be changed 
%
par         = partran;
I           = partran(1);
T           = partran(2);
tem         = zeros(T,I*I);
i1          = 14+10*I+5*I*I+3*T*I+2*T*I*I;
i2          = i1+T*I*I;
tem(:)      = i1+1:i2;
i3          = tem(1,12);
i4          = tem(T,12);

newice      = 0+(.05-0)*ones(T,1)./(1+exp(-([1:T]'-5)/(2*.2)));
par(i3:i4)  = newice;

%
% Apply a Newton's method to update guesses
%
X0          = Xtran(:);
nX          = length(X0);
del         = max(abs(X0)*1e-4,1e-8);
for it=1:10;
  res       = mwtranadj(X0,par);
  for i=1:nX;
    Xp      = X0;
    Xp(i)   = X0(i)+del(i); 
    dr(:,i) = (mwtranadj(Xp,par)-res)/del(i);
  end;
  S         = sparse(dr);
  X1        = X0-S\res;
  nrm       = sqrt(sum((X1-X0).^2))/length(X0);
  if (nrm<1e-10);break;end; 
  X0        = X1;
end;

save mw5x.dat X0 -ascii
save mw5p.dat par -ascii


%
% Case 6a. EU raises costs on trade from UK, ice=0==>.05
%

clear
load ../../steady/cases/XPtran1adj1.mat

%
% Find indicies in ice matrix to be changed 
%
par         = partran;
I           = partran(1);
T           = partran(2);
tem         = zeros(T,I*I);
i1          = 14+10*I+5*I*I+3*T*I+2*T*I*I;
i2          = i1+T*I*I;
tem(:)      = i1+1:i2;
i1          = tem(1,8);
i2          = tem(T,8);
newice      = 0+(.05-0)*ones(T,1)./(1+exp(-([1:T]'-5)/(2*.2)));
par(i1:i2)  = newice;

%
% Apply a Newton's method to update guesses
%
X0          = Xtran(:);
nX          = length(X0);
del         = max(abs(X0)*1e-4,1e-8);
for it=1:10;
  res       = mwtranadj(X0,par);
  for i=1:nX;
    Xp      = X0;
    Xp(i)   = X0(i)+del(i); 
    dr(:,i) = (mwtranadj(Xp,par)-res)/del(i);
  end;
  S         = sparse(dr);
  X1        = X0-S\res;
  nrm       = sqrt(sum((X1-X0).^2))/length(X0);
  if (nrm<1e-10);break;end; 
  X0        = X1;
end;

save mw6x.dat X0 -ascii
save mw6p.dat par -ascii


%
% Case 7a. UK,EU raise costs on trade from each other, ice=0==>.05
%

clear
load ../../steady/cases/XPtran1adj1.mat

%
% Find indicies in ice matrix to be changed 
%
par         = partran;
I           = partran(1);
T           = partran(2);
tem         = zeros(T,I*I);
i1          = 14+10*I+5*I*I+3*T*I+2*T*I*I;
i2          = i1+T*I*I;
tem(:)      = i1+1:i2;
i1          = tem(1,8);
i2          = tem(T,8);
i3          = tem(1,12);
i4          = tem(T,12);

newice      = 0+(.05-0)*ones(T,1)./(1+exp(-([1:T]'-5)/(2*.2)));
par(i1:i2)  = newice;
par(i3:i4)  = newice;

%
% Apply a Newton's method to update guesses
%
X0          = Xtran(:);
nX          = length(X0);
del         = max(abs(X0)*1e-4,1e-8);
for it=1:10;
  res       = mwtranadj(X0,par);
  for i=1:nX;
    Xp      = X0;
    Xp(i)   = X0(i)+del(i); 
    dr(:,i) = (mwtranadj(Xp,par)-res)/del(i);
  end;
  S         = sparse(dr);
  X1        = X0-S\res;
  nrm       = sqrt(sum((X1-X0).^2))/length(X0);
  if (nrm<1e-10);break;end; 
  X0        = X1;
end;

save mw7x.dat X0 -ascii
save mw7p.dat par -ascii


%
% Case 8a. UK raises costs on FDI from EU, sig=1==>.95
%          and costs on trade from EU, ice=0==>.05
%

clear
load ../../steady/cases/XPtran1adj1.mat

%
% Find indicies in sig matrix to be changed 
%
par         = partran;
I           = partran(1);
T           = partran(2);
tem         = zeros(T,I*I);
i1          = 14+10*I+5*I*I+3*T*I+T*I*I;
i2          = i1+T*I*I;
tem(:)      = i1+1:i2;
i3          = tem(1,12);
i4          = tem(T,12);
newsig      = 1+(.95-1)*ones(T,1)./(1+exp(-([1:T]'-5)/(2*.2)));
par(i3:i4)  = newsig;

%
% Find indicies in ice matrix to be changed 
%
tem         = zeros(T,I*I);
i1          = 14+10*I+5*I*I+3*T*I+2*T*I*I;
i2          = i1+T*I*I;
tem(:)      = i1+1:i2;
i3          = tem(1,12);
i4          = tem(T,12);
newice      = 0+(.05-0)*ones(T,1)./(1+exp(-([1:T]'-5)/(2*.2)));
par(i3:i4)  = newice;

%
% Apply a Newton's method to update guesses
%
X0          = Xtran(:);
nX          = length(X0);
del         = max(abs(X0)*1e-4,1e-8);
for it=1:10;
  res       = mwtranadj(X0,par);
  for i=1:nX;
    Xp      = X0;
    Xp(i)   = X0(i)+del(i); 
    dr(:,i) = (mwtranadj(Xp,par)-res)/del(i);
  end;
  S         = sparse(dr);
  X1        = X0-S\res;
  nrm       = sqrt(sum((X1-X0).^2))/length(X0);
  if (nrm<1e-10);break;end; 
  X0        = X1;
end;

save mw8x.dat X0 -ascii
save mw8p.dat par -ascii


%
% Case 9a. EU raises costs on FDI from UK, sig=1==>.95
%          and costs on trade from UK, ice=0==>.05
%

clear
load ../../steady/cases/XPtran1adj1.mat

%
% Find indicies in sig matrix to be changed 
%
par         = partran;
I           = partran(1);
T           = partran(2);
tem         = zeros(T,I*I);
i1          = 14+10*I+5*I*I+3*T*I+T*I*I;
i2          = i1+T*I*I;
tem(:)      = i1+1:i2;
i1          = tem(1,8);
i2          = tem(T,8);
newsig      = 1+(.95-1)*ones(T,1)./(1+exp(-([1:T]'-5)/(2*.2)));
par(i1:i2)  = newsig;

%
% Find indicies in ice matrix to be changed 
%
tem         = zeros(T,I*I);
i1          = 14+10*I+5*I*I+3*T*I+2*T*I*I;
i2          = i1+T*I*I;
tem(:)      = i1+1:i2;
i1          = tem(1,8);
i2          = tem(T,8);
newice      = 0+(.05-0)*ones(T,1)./(1+exp(-([1:T]'-5)/(2*.2)));
par(i1:i2)  = newice;

%
% Apply a Newton's method to update guesses
%
X0          = Xtran(:);
nX          = length(X0);
del         = max(abs(X0)*1e-4,1e-8);
for it=1:10;
  res       = mwtranadj(X0,par);
  for i=1:nX;
    Xp      = X0;
    Xp(i)   = X0(i)+del(i); 
    dr(:,i) = (mwtranadj(Xp,par)-res)/del(i);
  end;
  S         = sparse(dr);
  X1        = X0-S\res;
  nrm       = sqrt(sum((X1-X0).^2))/length(X0);
  if (nrm<1e-10);break;end; 
  X0        = X1;
end;

save mw9x.dat X0 -ascii
save mw9p.dat par -ascii


%
% Case 10a. UK,EU raise costs on trade and FDI from each other, (sig & ice)
%

clear
load ../../steady/cases/XPtran1adj1.mat

%
% Find indicies in sig matrix to be changed 
%
par         = partran;
I           = partran(1);
T           = partran(2);
tem         = zeros(T,I*I);
i1          = 14+10*I+5*I*I+3*T*I+T*I*I;
i2          = i1+T*I*I;
tem(:)      = i1+1:i2;
i1          = tem(1,8);
i2          = tem(T,8);
i3          = tem(1,12);
i4          = tem(T,12);
newsig      = 1+(.95-1)*ones(T,1)./(1+exp(-([1:T]'-5)/(2*.2)));
par(i1:i2)  = newsig;
par(i3:i4)  = newsig;

%
% Find indicies in ice matrix to be changed 
%
tem         = zeros(T,I*I);
i1          = 14+10*I+5*I*I+3*T*I+2*T*I*I;
i2          = i1+T*I*I;
tem(:)      = i1+1:i2;
i1          = tem(1,8);
i2          = tem(T,8);
i3          = tem(1,12);
i4          = tem(T,12);

newice      = 0+(.05-0)*ones(T,1)./(1+exp(-([1:T]'-5)/(2*.2)));
par(i1:i2)  = newice;
par(i3:i4)  = newice;

%
% Apply a Newton's method to update guesses
%
X0          = Xtran(:);
nX          = length(X0);
del         = max(abs(X0)*1e-4,1e-8);
for it=1:10;
  res       = mwtranadj(X0,par);
  for i=1:nX;
    Xp      = X0;
    Xp(i)   = X0(i)+del(i); 
    dr(:,i) = (mwtranadj(Xp,par)-res)/del(i);
  end;
  S         = sparse(dr);
  X1        = X0-S\res;
  nrm       = sqrt(sum((X1-X0).^2))/length(X0);
  if (nrm<1e-10);break;end; 
  X0        = X1;
end;

save mw10x.dat X0 -ascii
save mw10p.dat par -ascii


% Case 11a. UK,EU raise costs on trade and FDI from each other, (sig & ice)
%           UK lowers costs on FDI from US
%

clear
load ../../steady/cases/XPtran1adj1.mat

%
% Find indicies in sig matrix to be changed 
%
par         = partran;
I           = partran(1);
T           = partran(2);
tem         = zeros(T,I*I);
i1          = 14+10*I+5*I*I+3*T*I+T*I*I;
i2          = i1+T*I*I;
tem(:)      = i1+1:i2;
i1          = tem(1,8);
i2          = tem(T,8);
i3          = tem(1,12);
i4          = tem(T,12);
i5          = tem(1,11);
i6          = tem(T,11);
newsig      = 1+(.95-1)*ones(T,1)./(1+exp(-([1:T]'-5)/(2*.2)));
newsig2     = .8647+(.9147-.8647)*ones(T,1)./(1+exp(-([1:T]'-5)/(2*.2)));
par(i1:i2)  = newsig;
par(i3:i4)  = newsig;
par(i5:i6)  = newsig2;

%
% Find indicies in ice matrix to be changed 
%
tem         = zeros(T,I*I);
i1          = 14+10*I+5*I*I+3*T*I+2*T*I*I;
i2          = i1+T*I*I;
tem(:)      = i1+1:i2;
i1          = tem(1,8);
i2          = tem(T,8);
i3          = tem(1,12);
i4          = tem(T,12);
i5          = tem(1,11);
i6          = tem(T,11);
newice      = 0+(.05-0)*ones(T,1)./(1+exp(-([1:T]'-5)/(2*.2)));
par(i1:i2)  = newice;
par(i3:i4)  = newice;

%
% Apply a Newton's method to update guesses
%
X0          = Xtran(:);
nX          = length(X0);
del         = max(abs(X0)*1e-4,1e-8);
for it=1:10;
  res       = mwtranadj(X0,par);
  for i=1:nX;
    Xp      = X0;
    Xp(i)   = X0(i)+del(i);
    dr(:,i) = (mwtranadj(Xp,par)-res)/del(i);
  end;
  S         = sparse(dr);
  X1        = X0-S\res;
  nrm       = sqrt(sum((X1-X0).^2))/length(X0);
  disp([it,nrm])
  if (nrm<1e-10);break;end;
  X0        = X1;
end;

save mw11x.dat X0 -ascii
save mw11p.dat par -ascii


%
% Case 12a. UK,EU raise costs on trade and FDI from each other, (sig & ice)
%           UK lowers costs on trade from US
%

clear
load ../../steady/cases/XPtran1adj1.mat

%
% Find indicies in sig matrix to be changed 
%
par         = partran;
I           = partran(1);
T           = partran(2);
tem         = zeros(T,I*I);
i1          = 14+10*I+5*I*I+3*T*I+T*I*I;
i2          = i1+T*I*I;
tem(:)      = i1+1:i2;
i1          = tem(1,8);
i2          = tem(T,8);
i3          = tem(1,12);
i4          = tem(T,12);
newsig      = 1+(.95-1)*ones(T,1)./(1+exp(-([1:T]'-5)/(2*.2)));
par(i1:i2)  = newsig;
par(i3:i4)  = newsig;

%
% Find indicies in ice matrix to be changed 
%
tem         = zeros(T,I*I);
i1          = 14+10*I+5*I*I+3*T*I+2*T*I*I;
i2          = i1+T*I*I;
tem(:)      = i1+1:i2;
i1          = tem(1,8);
i2          = tem(T,8);
i3          = tem(1,12);
i4          = tem(T,12);
i5          = tem(1,11);
i6          = tem(T,11);
newice      = 0+(.05-0)*ones(T,1)./(1+exp(-([1:T]'-5)/(2*.2)));
newice2     = .2141+(.1641-.2141)*ones(T,1)./(1+exp(-([1:T]'-5)/(2*.2)));
par(i1:i2)  = newice;
par(i3:i4)  = newice;
par(i5:i6)  = newice2;

%
% Apply a Newton's method to update guesses
%
X0          = Xtran(:);
nX          = length(X0);
del         = max(abs(X0)*1e-4,1e-8);
for it=1:10;
  res       = mwtranadj(X0,par);
  for i=1:nX;
    Xp      = X0;
    Xp(i)   = X0(i)+del(i); 
    dr(:,i) = (mwtranadj(Xp,par)-res)/del(i);
  end;
  S         = sparse(dr);
  X1        = X0-S\res;
  nrm       = sqrt(sum((X1-X0).^2))/length(X0);
  disp([it,nrm])
  if (nrm<1e-10);break;end; 
  X0        = X1;
end;

save mw12x.dat X0 -ascii
save mw12p.dat par -ascii


%
% Case 13a. UK,EU raise costs on trade and FDI from each other, (sig & ice)
%           UK lowers costs on trade and FDI from US
%

clear
load ../../steady/cases/XPtran1adj1.mat

%
% Find indicies in sig matrix to be changed 
%
par         = partran;
I           = partran(1);
T           = partran(2);
tem         = zeros(T,I*I);
i1          = 14+10*I+5*I*I+3*T*I+T*I*I;
i2          = i1+T*I*I;
tem(:)      = i1+1:i2;
i1          = tem(1,8);
i2          = tem(T,8);
i3          = tem(1,12);
i4          = tem(T,12);
i5          = tem(1,11);
i6          = tem(T,11);
newsig      = 1+(.95-1)*ones(T,1)./(1+exp(-([1:T]'-5)/(2*.2)));
newsig2     = .8647+(.9147-.8647)*ones(T,1)./(1+exp(-([1:T]'-5)/(2*.2)));
par(i1:i2)  = newsig;
par(i3:i4)  = newsig;
par(i5:i6)  = newsig2;

%
% Find indicies in ice matrix to be changed 
%
tem         = zeros(T,I*I);
i1          = 14+10*I+5*I*I+3*T*I+2*T*I*I;
i2          = i1+T*I*I;
tem(:)      = i1+1:i2;
i1          = tem(1,8);
i2          = tem(T,8);
i3          = tem(1,12);
i4          = tem(T,12);
i5          = tem(1,11);
i6          = tem(T,11);
newice      = 0+(.05-0)*ones(T,1)./(1+exp(-([1:T]'-5)/(2*.2)));
newice2     = .2141+(.1641-.2141)*ones(T,1)./(1+exp(-([1:T]'-5)/(2*.2)));
par(i1:i2)  = newice;
par(i3:i4)  = newice;
par(i5:i6)  = newice2;

%
% Apply a Newton's method to update guesses
%
X0          = Xtran(:);
nX          = length(X0);
del         = max(abs(X0)*1e-4,1e-8);
for it=1:10;
  res       = mwtranadj(X0,par);
  for i=1:nX;
    Xp      = X0;
    Xp(i)   = X0(i)+del(i); 
    dr(:,i) = (mwtranadj(Xp,par)-res)/del(i);
  end;
  S         = sparse(dr);
  X1        = X0-S\res;
  nrm       = sqrt(sum((X1-X0).^2))/length(X0);
  disp([it,nrm])
  if (nrm<1e-10);break;end; 
  X0        = X1;
end;

save mw13x.dat X0 -ascii
save mw13p.dat par -ascii


%
% Case 14a. UK,EU raise costs on trade and FDI from each other, (sig & ice)
%           UK lowers costs on trade and FDI from all other countries
%

clear
load ../../steady/cases/XPtran1adj1.mat

%
% Find indicies in sig matrix to be changed 
%
par         = partran;
I           = partran(1);
T           = partran(2);
tem         = zeros(T,I*I);
i1          = 14+10*I+5*I*I+3*T*I+T*I*I;
i2          = i1+T*I*I;
tem(:)      = i1+1:i2;
i1          = tem(1,8);
i2          = tem(T,8);
i3          = tem(1,12);
i4          = tem(T,12);
i5          = tem(1,11);
i6          = tem(T,11);
i7          = tem(1,14);
i8          = tem(T,14);
i9          = tem(1,15);
i10         = tem(T,15);
newsig      = 1+(.95-1)*ones(T,1)./(1+exp(-([1:T]'-5)/(2*.2)));
newsig2     = .8647+(.9147-.8647)*ones(T,1)./(1+exp(-([1:T]'-5)/(2*.2)));
newsig3     = .4521+(.5021-.4521)*ones(T,1)./(1+exp(-([1:T]'-5)/(2*.2)));
newsig4     = .7032+(.7532-.7032)*ones(T,1)./(1+exp(-([1:T]'-5)/(2*.2)));
par(i1:i2)  = newsig;
par(i3:i4)  = newsig;
par(i5:i6)  = newsig2;
par(i7:i8)  = newsig3;
par(i9:i10) = newsig4;

%
% Find indicies in ice matrix to be changed 
%
tem         = zeros(T,I*I);
i1          = 14+10*I+5*I*I+3*T*I+2*T*I*I;
i2          = i1+T*I*I;
tem(:)      = i1+1:i2;
i1          = tem(1,8);
i2          = tem(T,8);
i3          = tem(1,12);
i4          = tem(T,12);
i5          = tem(1,11);
i6          = tem(T,11);
i9          = tem(1,15);
i10         = tem(T,15);
newice      = 0+(.05-0)*ones(T,1)./(1+exp(-([1:T]'-5)/(2*.2)));
newice2     = .2141+(.1641-.2141)*ones(T,1)./(1+exp(-([1:T]'-5)/(2*.2)));
newice4     = .0215+(.0-.0215)*ones(T,1)./(1+exp(-([1:T]'-5)/(2*.2)));
par(i1:i2)  = newice;
par(i3:i4)  = newice;
par(i5:i6)  = newice2;
par(i9:i10) = newice4;

%
% Apply a Newton's method to update guesses
%
X0          = Xtran(:);
nX          = length(X0);
del         = max(abs(X0)*1e-4,1e-8);
for it=1:10;
  res       = mwtranadj(X0,par);
  for i=1:nX;
    Xp      = X0;
    Xp(i)   = X0(i)+del(i); 
    dr(:,i) = (mwtranadj(Xp,par)-res)/del(i);
  end;
  S         = sparse(dr);
  X1        = X0-S\res;
  nrm       = sqrt(sum((X1-X0).^2))/length(X0);
  disp([it,nrm])
  if (nrm<1e-10);break;end; 
  X0        = X1;
end;

save mw14x.dat X0 -ascii
save mw14p.dat par -ascii


